package com.gic.store.service.outer;

import com.gic.api.base.commons.Page;
import com.gic.api.base.commons.ServiceResponse;
import com.gic.commons.util.EntityUtil;
import com.gic.store.dao.mapper.TabStoreGroupMapper;
import com.gic.store.dto.StoreBrandDTO;
import com.gic.store.dto.StoreBusinessTimeDTO;
import com.gic.store.dto.StoreDTO;
import com.gic.store.dto.StorePhotoDTO;
import com.gic.store.entity.*;
import com.gic.store.service.*;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.Arrays;
import java.util.List;
import java.util.stream.Collectors;

/**
 * @author zhiwj
 * @date 2019/6/27
 */
@Service("storeApiService")
public class StoreApiServiceImpl implements StoreApiService {

    @Autowired
    private StoreService storeService;
    @Autowired
    private StoreBrandService storeBrandService;
    @Autowired
    private StorePhotoService storePhotoService;
    @Autowired
    private StoreBusinessTimeService storeBusinessTimeService;
    @Autowired
    private TabStoreGroupMapper tabStoreGroupMapper;


    @Override
    @Transactional(rollbackFor = Exception.class)
    public ServiceResponse<Integer> saveOrUpdate(StoreDTO storeDTO) {
        // 门店自身信息
        if (storeDTO.getStoreId() == null) {
            Integer id = storeService.save(storeDTO);
            storeDTO.setStoreId(id);
        } else {
            storeService.update(storeDTO);
        }
        // 门店图片
        List<Integer> delPhotos = null;
        if (StringUtils.isNotEmpty(storeDTO.getDelPhotos())) {
            List<String> photoIds = Arrays.asList(storeDTO.getDelPhotos().split(","));
            delPhotos = photoIds.stream().map(Integer::parseInt).collect(Collectors.toList());
        }
        storePhotoService.editStoreImage(storeDTO.getEnterpriseId(), storeDTO.getStoreId(), storeDTO.getPhotoList(), delPhotos);
        // 营业时间
        List<Integer> delBusinessTimes = null;
        if (StringUtils.isNotEmpty(storeDTO.getDelBusinessTimes())) {
            List<String> delBusinessTimeIds = Arrays.asList(storeDTO.getDelBusinessTimes().split(","));
            delBusinessTimes = delBusinessTimeIds.stream().map(Integer::parseInt).collect(Collectors.toList());
        }
        storeBusinessTimeService.editStoreBusinessTime(storeDTO.getEnterpriseId(), storeDTO.getStoreId(), storeDTO.getBusinessTimeList(), delBusinessTimes);
        return ServiceResponse.success();
    }

    @Override
    public ServiceResponse<Page<StoreDTO>> listStore(StoreDTO storeDTO, Integer pageNum, Integer pageSize) {
        return null;
    }

    @Override
    public ServiceResponse<StoreDTO> getStoreById(Integer enterpriseId, Integer storeId) {
        TabStore store = storeService.getById(storeId);
        StoreDTO storeDTO = EntityUtil.changeEntityByOrika(StoreDTO.class, store);
        TabStoreGroup storeGroup = tabStoreGroupMapper.selectByPrimaryKey(storeId);
        if (storeGroup != null) {
            storeDTO.setStoreGroupName(storeGroup.getStoreGroupName());
        }
        List<TabStorePhoto> tabPhotoList = storePhotoService.listStorePhoto(storeDTO.getEnterpriseId(), storeDTO.getStoreId());
        List<StorePhotoDTO> photoDTOList = EntityUtil.changeEntityListByOrika(StorePhotoDTO.class, tabPhotoList);
        storeDTO.setPhotoList(photoDTOList);
        List<TabStoreBusinessTime> tabBusinessTimeList = storeBusinessTimeService.listBusinessTime(store.getStoreId());
        List<StoreBusinessTimeDTO> businessTimeDTOList = EntityUtil.changeEntityListByOrika(StoreBusinessTimeDTO.class, tabBusinessTimeList);
        storeDTO.setBusinessTimeList(businessTimeDTOList);
        List<TabStoreBrand> storeBrandList = storeBrandService.listStoreBrandByIds(store.getBrandIds());
        List<StoreBrandDTO> brandDTOList = EntityUtil.changeEntityListByOrika(StoreBrandDTO.class, storeBrandList);
        storeDTO.setBrandList(brandDTOList);
        return ServiceResponse.success(storeDTO);
    }

    @Override
    public ServiceResponse<Integer> costStoreMove(String storeIds, String toStoreId) {
        return null;
    }
}
